API documentation
=================

tdt.util
--------
.. automodule:: tdt.util

tdt.DSPProject
--------------
.. autoclass:: tdt.DSPProject
    :members:
    :inherited-members:

tdt.DSPCircuit
--------------
.. autoclass:: tdt.DSPCircuit
    :members:
    :inherited-members:

tdt.DSPBuffer
-------------
.. autoclass:: tdt.DSPBuffer
    :members:
    :inherited-members:

tdt.convert
-----------
.. automodule:: tdt.convert
    :members:
